package de.intevation.artifacts;

/**
 * Interface of an artifact producing factory.
 *
 * @author Sascha L. Teichmann (sascha.teichmann@intevation.de)
 */
public interface ArtifactFactory
{
    /**
     * The short name of this factory.
     * @return the name of this factory.
     */
    String getName();

    /**
     * Description of this factory.
     * @return description of the factory.
     */
    String getDescription();

    /**
     * Create a new artifact of certain type, given a general purpose context and
     * an identifier.
     * @param context a context from the ArtifactDatabase.
     * @param identifier unique identifer for the new artifact
     * @return a new {@linkplain de.intevation.artifacts.Artifact Artifact}
     */
    Artifact createArtifact(Object context, String identifier);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
